@@ -18,16 +18,16 @@ import string
 
 from discord.ext import commands
 
-from sciolyid.data import database, get_aliases, get_wiki_url, logger
-from sciolyid.functions import (
-    CustomCooldown,
+from sciolyid.data import alias_id_list, database, get_aliases, get_wiki_url, logger
+from sciolyid.data_functions import (
     incorrect_increment,
     item_setup,
     score_increment,
     session_increment,
-    spellcheck_list,
     streak_increment,
 )
+from sciolyid.functions import CustomCooldown
+from sciolyid.util import better_spellcheck
 
 
 class Check(commands.Cog):
@@ -63,7 +63,7 @@ class Check(commands.Cog):
                     correct = arg in correct_list
                 else:
                     logger.info("spelling leniency")
-                    correct = spellcheck_list(arg, correct_list)
+                    correct = better_spellcheck(arg, correct_list, alias_id_list)
             else:
                 logger.info("no race")
                 if database.hget(f"session.data:{ctx.author.id}", "strict"):
@@ -71,7 +71,7 @@ class Check(commands.Cog):
                     correct = arg in correct_list
                 else:
                     logger.info("spelling leniency")
-                    correct = spellcheck_list(arg, correct_list)
+                    correct = better_spellcheck(arg, correct_list, alias_id_list)
 
             if correct:
                 logger.info("correct")
@@ -88,9 +88,9 @@ class Check(commands.Cog):
                 )
 
                 await ctx.send(
-                    "Correct! Good job!"
+                    f"Correct! Good job! The image was **{current_item}**."
                     if not database.exists(f"race.data:{ctx.channel.id}")
-                    else f"**{ctx.author.mention}**, you are correct!"
+                    else f"**{ctx.author.mention}**, you are correct! The image was **{current_item}**."
                 )
                 url = get_wiki_url(ctx, current_item)
                 await ctx.send(
@@ -111,12 +111,15 @@ class Check(commands.Cog):
                         await race.stop_race(ctx)
                     else:
                         logger.info("auto sending next image")
-                        group, bw = database.hmget(
-                            f"race.data:{ctx.channel.id}", ["group", "bw"]
+                        group, state, bw = database.hmget(
+                            f"race.data:{ctx.channel.id}", ["group", "state", "bw"]
                         )
                         media = self.bot.get_cog("Media")
                         await media.send_pic(
-                            ctx, group.decode("utf-8"), bw.decode("utf-8")
+                            ctx,
+                            group.decode("utf-8"),
+                            state.decode("utf-8"),
+                            bw.decode("utf-8"),
                         )
 
             else:
